@@ -446,7 +446,7 @@ if isnotebook():
 package_files = {}
 
 
-# In[41]:
+# In[50]:
 
 
 package_files['setup.py'] = r"""from distutils.core import setup
@@ -458,8 +458,8 @@ setup(
   description = 'lx',   # Give a short description about your library
   author = 'lx',                   # Type in your name
   author_email = 'hx2983113@gmail.com',      # Type in your E-Mail
-  url = 'https://github.com/hx2983113/lx',   # Provide either the link to your github or to your website
-  download_url = 'https://github.com/hx2983113/lx/archive/0.18.tar.gz',    # I explain this later on
+  #url = 'https://github.com/hx2983113/lx',   # Provide either the link to your github or to your website
+  #download_url = 'https://github.com/hx2983113/lx/archive/0.18.tar.gz',    # I explain this later on
   keywords = [],   # Keywords that define your package best
   install_requires=[
       {requirements}
@@ -477,7 +477,7 @@ setup(
 )""".format(requirements=", ".join(["'" + r + "'" for r in requirements]))
 
 
-# In[42]:
+# In[51]:
 
 
 package_files['setup.cfg'] = r"""# Inside of setup.cfg
@@ -486,7 +486,7 @@ description-file = README.md
 """
 
 
-# In[43]:
+# In[52]:
 
 
 package_files['LICENSE.txt'] = r"""MIT License
@@ -508,25 +508,25 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE."""
 
 
-# In[44]:
+# In[53]:
 
 
 package_files['README.md'] = ""
 
 
-# In[45]:
+# In[54]:
 
 
 get_ipython().system(' jupyter nbconvert --to script lx.ipynb')
 
 
-# In[47]:
+# In[55]:
 
 
 package_files['lx/__init__.py'] = txtread("lx.py")
 
 
-# In[48]:
+# In[56]:
 
 
 def shell(cmd):
@@ -534,7 +534,7 @@ def shell(cmd):
     return result.stdout.decode()
 
 
-# In[49]:
+# In[57]:
 
 
 if isnotebook():
